##################################################
## CTSM-R @: www.ctsm.info
## Simulation of the state
## By Jan Kloppenborg Moller (jkmo@dtu.dk)
## License: GPL v2
##################################################

rm(list=ls())

## Set parameters
k<-10000
alpha<-6
beta<-alpha/230

## Plot distribution
x<-seq(0,700,by=1)
plot(x,dgamma(x,alpha,beta),type="l",xlab="t",ylab="f(t)")


## initialize vectors
t<-seq(0,4*3600,by=1);
p<-numeric(length(t));
q<-numeric(length(t))

px<-seq(0.3,2.5,by=0.001);
qx<-seq(0,3.5,by=0.001)


xny<-function(x,x0){
  d<-x*0
  for(i in 1:length(x0)){
    d<-d+(x-x0[i])^2
  }
  d<-d/sum(d)
  F<-cumsum(d)
  r<-runif(1)
  xny<-x[sort(abs(F-r),index.return=TRUE)$ix[1]]
  return(xny)
}

## Simulate time shifts
set.seed(24452)
sp<-rgamma(k,alpha,beta)
sq<-rgamma(k,alpha,beta)
sp<-round(sp)
sq<-round(sq)
sp<-sp[cumsum(sp)<4*3600]
sq<-sq[cumsum(sq)<4*3600]
sp<-c(0,cumsum(sp),4*3600)
sq<-c(0,cumsum(sq),4*3600)

## Simulate  DP and Q
p0<-round(runif(1,0.3,2.5),digits=3)
q0<-round(runif(1,0,3.5),digits=3)
p[1]<-p0
for(i in 2:length(sp)){
  p[t>sp[i-1] & t<=sp[i]]<-p0[i-1]
  p0<-c(p0,xny(px,p0))
}

q[1]<-q0
for(i in 2:length(sp)){
  q[t>sq[i-1] & t<=sq[i]]<-q0[i-1]
  q0<-c(q0,xny(qx,q0))
}

## 
P<-matrix(p,ncol=1)
Q<-matrix(q,ncol=1)
SP<-diff(sp)
SQ<-diff(sq)

for(j in 1:5){
    sp<-rgamma(k,alpha,beta);
    sq<-rgamma(k,alpha,beta)
    sp<-round(sp);
    sq<-round(sq)
    sp<-sp[cumsum(sp)<4*3600];
    sq<-sq[cumsum(sq)<4*3600]
    sp<-c(0,cumsum(sp),4*3600);
    sq<-c(0,cumsum(sq),4*3600)
    p0<-xny(px,P[1, ])
    q0<-xny(qx,Q[1, ])
    p<-numeric(length(t));q<-numeric(length(t))

    p[1]<-p0
    for(i in 2:length(sp)){
        p[t>sp[i-1] & t<=sp[i]]<-p0
        p0.tmp<-as.numeric(levels(as.factor(as.vector(P[t>sp[i-1] & t<=sp[i+1], ]))))
        p0<-xny(px,c(p0.tmp,p0))
    }

    q[1]<-q0
    for(i in 2:length(sq)){
        q[t>sq[i-1] & t<=sq[i]]<-q0
        q0.tmp<-as.numeric(levels(as.factor(as.vector(Q[t>sq[i-1] & t<=sq[i+1], ]))))
        q0<-xny(qx,c(q0.tmp,q0))
    }

    P<-cbind(P,p)
    SP<-c(SP,diff(sp))
    Q<-cbind(Q,q)
    SQ<-c(SQ,diff(sq))
    print(j)
}

T01 <- cbind(t, P[ ,1], Q[ ,1])
T02 <- cbind(t, P[ ,2], Q[ ,2])
T03 <- cbind(t, P[ ,3], Q[ ,3])
T04 <- cbind(t, P[ ,4], Q[ ,4])
T05 <- cbind(t, P[ ,5], Q[ ,5])


##################################################
## Based on pilot study
## new pmax =2.3
## if p<1 qmax=0.2
## if p>1 qmax=0.4
##################################################

px<-seq(0.3,2.3,by=0.001)

xny<-function(x,x0,shape1,shape2){
  d<-dbeta((x-min(x))/(diff(range(x))),shape1=shape1,shape2=shape2)*
    abs(x-x0)
  d<-d/sum(d)
  F<-cumsum(d)
  r<-runif(1)
  xny<-x[sort(abs(F-r),index.return=TRUE)$ix[1]]
  return(xny)
}



shape1p<-c(1,5,1,5,3);shape2p<-c(5,1,5,1,3)
shape1q<-c(1,1,5,5,3);shape2q<-c(5,5,1,1,3)

cbind(shape1p,shape1q,shape2p,shape2q)


P<-matrix(nrow=14401,ncol=5)
Q<-matrix(nrow=14401,ncol=5)

k<-10000
set.seed(265254436)
for(j in 1:5){
  sp<-rgamma(k,alpha,beta);sq<-rgamma(k,alpha,beta)
  sp<-round(sp);sq<-round(sq)
  sp<-sp[cumsum(sp)<4*3600];sq<-sq[cumsum(sq)<4*3600]
  sp<-c(0,cumsum(sp),4*3600);sq<-c(0,cumsum(sq),4*3600)
  
  p0<-round(
        rbeta(1,shape1=shape1p[j],shape=shape2p[j])*diff(range(px))+min(px),
        digits=3)

  qx<-seq(0.2,3.5,by=0.001)
  if(p0>1){qx<-seq(0.4,3.5,by=0.001)}
 
  q0<-round(
        rbeta(1,shape1=shape1q[j],shape=shape2q[j])*diff(range(qx))+min(qx),
        digits=3)
  p[1]<-p0
  for(i in 2:length(sp)){
    p[t>sp[i-1] & t<=sp[i]]<-p0
    p0<-xny(px,p0,shape1p[j],shape2p[j])
  }

  q[1]<-q0
  for(i in 2:length(sq)){
    q[t>sq[i-1] & t<=sq[i]]<-q0
    qx<-seq(0.2,3.5,by=0.001)
    if(p[t==sq[i-1]]>1){qx<-seq(0.4,3.5,by=0.001)}
    q0<-xny(qx,q0,shape1q[j],shape2q[j])
  }
  P[ ,j]<-p
  Q[ ,j]<-q
}

sum(P[ ,2:5]>1 & Q[ ,2:5]<0.4)

sum(P[ ,1]>1 & Q[ ,1]<0.4)
Q[P>1 & Q<0.4] <- Q[P>1 & Q<0.4]+0.2

T06 <- cbind(t,P[ ,1],Q[ ,1])
T07 <- cbind(t,P[ ,2],Q[ ,2])
T08 <- cbind(t,P[ ,3],Q[ ,3])
T09 <- cbind(t,P[ ,4],Q[ ,4])
T10 <- cbind(t,P[ ,5],Q[ ,5])


##################################################
# New time constants
##################################################

shape1p<-cbind(seq(1,5,length=14401),seq(5,1,length=14401),
               seq(1,5,length=14401),seq(5,1,length=14401))
shape2p<-cbind(seq(5,1,length=14401),seq(1,5,length=14401),
               seq(5,1,length=14401),seq(1,5,length=14401))
shape1q<-cbind(seq(1,5,length=14401),seq(5,1,length=14401),
               seq(5,1,length=14401),seq(1,5,length=14401))
shape2q<-cbind(seq(5,1,length=14401),seq(1,5,length=14401),
               seq(1,5,length=14401),seq(5,1,length=14401))


k<-10000
alpha<-12
beta<-alpha/460

x<-seq(0,1000,by=1)
matplot(x,cbind(dgamma(x,6,6/230),dgamma(x,alpha,beta)),type="l",xlab="t [sec]",ylab="f(t)")
legend(x=1000,y=0.0045,legend=c("Series 1-10","Series 11-20"),xjust=1,yjust=1,lty=1:2,col=1:2)


P<-matrix(nrow=14401,ncol=4)
Q<-matrix(nrow=14401,ncol=4)

k<-10000
set.seed(6543123)
for(j in 1:4){
  sp<-rgamma(k,alpha,beta);sq<-rgamma(k,alpha,beta)
  sp<-round(sp);sq<-round(sq)
  sp<-sp[cumsum(sp)<4*3600];sq<-sq[cumsum(sq)<4*3600]
  sp<-c(0,cumsum(sp),4*3600);sq<-c(0,cumsum(sq),4*3600)
  
  p0<-round(
        rbeta(1,shape1=shape1p[1,j],shape=shape2p[1,j])*diff(range(px))+min(px),
        digits=3)

  qx<-seq(0.2,3.5,by=0.001)
  if(p0>1){qx<-seq(0.4,3.5,by=0.001)}
 
  q0<-round(
        rbeta(1,shape1=shape1q[1,j],shape=shape2q[1,j])*diff(range(qx))+min(qx),
        digits=3)
  p[1]<-p0
  for(i in 2:length(sp)){
    p[t>sp[i-1] & t<=sp[i]]<-p0
    index<-t[t==sp[i]]
    p0<-xny(px,p0,shape1p[index,j],shape2p[index,j])
  }

  q[1]<-q0
  for(i in 2:length(sq)){
    q[t>sq[i-1] & t<=sq[i]]<-q0
    index<-t[t==sq[i]]
    qx<-seq(0.2,3.5,by=0.001)
    if(p[t==sq[i-1]]>1){qx<-seq(0.4,3.5,by=0.001)}
    q0<-xny(qx,q0,shape1q[index,j],shape2q[index,j])
  }
  P[ ,j]<-p
  Q[ ,j]<-q
}

sum(P>1 & Q<0.4)/prod(dim(P))

Q[P>1 & Q<0.4]<-Q[P>1 & Q<0.4]+0.2

T11 <- cbind(t,P[ ,1],Q[ ,1])
T12 <- cbind(t,P[ ,2],Q[ ,2])
T13 <- cbind(t,P[ ,3],Q[ ,3])
T14 <- cbind(t,P[ ,4],Q[ ,4])



shape1p<-cbind(c(rep(1,2880),seq(1,5,length=2880),rep(5,2880),
                 seq(5,1,length=2880),rep(1,2881)),
               c(rep(1,2880),seq(1,5,length=2880),rep(5,2880),
                 seq(5,1,length=2880),rep(1,2881)))
shape2p<-6-shape1p

shape1q<-cbind(shape1p[ ,1],shape2p[ ,2])
shape2q<-6-shape1q

P<-matrix(nrow=14401,ncol=2)
Q<-matrix(nrow=14401,ncol=2)

k<-10000
set.seed(985679)
for(j in 1:2){
  sp<-rgamma(k,alpha,beta);sq<-rgamma(k,alpha,beta)
  sp<-round(sp);sq<-round(sq)
  sp<-sp[cumsum(sp)<4*3600];sq<-sq[cumsum(sq)<4*3600]
  sp<-c(0,cumsum(sp),4*3600);sq<-c(0,cumsum(sq),4*3600)
  
  p0<-round(
        rbeta(1,shape1=shape1p[1,j],shape=shape2p[1,j])*diff(range(px))+min(px),
        digits=3)

  qx<-seq(0.2,3.5,by=0.001)
  if(p0>1){qx<-seq(0.4,3.5,by=0.001)}

  q0<-round(
        rbeta(1,shape1=shape1q[1,j],shape=shape2q[1,j])*diff(range(qx))+min(qx),
        digits=3)
  p[1]<-p0
  for(i in 2:length(sp)){
    p[t>sp[i-1] & t<=sp[i]]<-p0
    index<-t[t==sp[i]]
    p0<-xny(px,p0,shape1p[index,j],shape2p[index,j])
  }

  q[1]<-q0
  for(i in 2:length(sq)){
    q[t>sq[i-1] & t<=sq[i]]<-q0
    index<-t[t==sq[i]]
    qx<-seq(0.2,3.5,by=0.001)
    if(p[t==sq[i-1]]>1){qx<-seq(0.4,3.5,by=0.001)}
    q0<-xny(qx,q0,shape1q[index,j],shape2q[index,j])
  }
  P[ ,j]<-p
  Q[ ,j]<-q
}

sum(P>1 & Q<0.4)/prod(dim(P))

Q[P>1 & Q<0.4]<-Q[P>1 & Q<0.4]+0.2

T15 <- cbind(t,P[ ,1],Q[ ,1])
T16 <- cbind(t,P[ ,2],Q[ ,2])

##################################################
## Series 17-20
## Main idea is to create series different from the other
## 16 series 
P<-cbind(T01[ ,2],T02[ ,2],T03[ ,2],T04[ ,2],T05[ ,2],T06[ ,2],
         T07[ ,2],T08[ ,2],T09[ ,2],T10[ ,2],T11[ ,2],T12[ ,2],
         T13[ ,2],T14[ ,2],T15[ ,2],T16[ ,2])
Q<-cbind(T01[ ,3],T02[ ,3],T03[ ,3],T04[ ,3],T05[ ,3],T06[ ,3],
         T07[ ,3],T08[ ,3],T09[ ,3],T10[ ,3],T11[ ,3],T12[ ,3],
         T13[ ,3],T14[ ,3],T15[ ,3],T16[ ,3])


mp1<-mean(quantile((apply(P,2,mean)),probs=c(0,0.5)))
mq1<-mean(quantile((apply(Q,2,mean)),probs=c(0,0.5)))
mp2<-mean(quantile((apply(P,2,mean)),probs=c(0.5,1)))
mq2<-mean(quantile((apply(Q,2,mean)),probs=c(0.5,1)))

Ep1<-(mp1-min(px))/diff(range(px))
Ep2<-(mp2-min(px))/diff(range(px))
Eq1<-(mq1-min(qx))/diff(range(qx))
Eq2<-(mq2-min(qx))/diff(range(qx))

ap1<-seq(0.1,2,by=0.01)
bp1<-ap1*(1/Ep1-1)

ap1<-1;bp1<-ap1*(1/Ep1-1)
ap1;bp1

bp2<-1;ap2<-bp2*(1/Ep2-1)^-1
ap2;bp2

aq1<-1;bq1<-ap1*(1/Eq1-1)
aq1;bq1

bq2<-1;aq2<-bq2*(1/Eq2-1)^-1
aq2;bq2

shapeP<-rbind(c(ap1,bp1),c(ap1,bp1),c(ap2,bp2),c(ap2,bp2))
shapeQ<-rbind(c(aq1,bq1),c(aq2,bq2),c(aq1,bq1),c(aq2,bq2))


P<-matrix(nrow=14401,ncol=4)
Q<-matrix(nrow=14401,ncol=4)

k<-10000
set.seed(435256)
for(j in 1:4){
  sp<-rgamma(k,alpha,beta);sq<-rgamma(k,alpha,beta)
  sp<-round(sp);sq<-round(sq)
  sp<-sp[cumsum(sp)<4*3600];sq<-sq[cumsum(sq)<4*3600]
  sp<-c(0,cumsum(sp),4*3600);sq<-c(0,cumsum(sq),4*3600)
  
  p0<-round(
        rbeta(1,shape1=shapeP[j,1],shape=shapeP[j,2])*diff(range(px))+min(px),
        digits=3)

  qx<-seq(0.2,3.5,by=0.001)
  if(p0>1){qx<-seq(0.4,3.5,by=0.001)}

  q0<-round(
        rbeta(1,shape1=shapeQ[j,1],shape=shapeQ[j,2])*diff(range(qx))+min(qx),
        digits=3)
  p[1]<-p0
  for(i in 2:length(sp)){
    p[t>sp[i-1] & t<=sp[i]]<-p0
    p0<-round(
          rbeta(1,shape1=shapeP[j,1],shape=shapeP[j,2])*diff(range(px))+min(px),
          digits=3)
  }

  q[1]<-q0
  for(i in 2:length(sq)){
    q[t>sq[i-1] & t<=sq[i]]<-q0
    index<-t[t==sq[i]]
    qx<-seq(0.2,3.5,by=0.001)
    if(p[t==sq[i-1]]>1){qx<-seq(0.4,3.5,by=0.001)}

    q0<-round(
          rbeta(1,shape1=shapeQ[j,1],shape=shapeQ[j,2])*diff(range(qx))+min(qx),
          digits=3)
  }
  P[ ,j]<-p
  Q[ ,j]<-q
}

sum(P>1 & Q<0.4)/prod(dim(P))

Q[P>1 & Q<0.4]<-Q[P>1 & Q<0.4]+0.2

T17 <- cbind(t,P[ ,1],Q[ ,1])
T18 <- cbind(t,P[ ,2],Q[ ,2])
T19 <- cbind(t,P[ ,3],Q[ ,3])
T20 <- cbind(t,P[ ,4],Q[ ,4])


##################################################
## Some plots
##################################################
P<-cbind(T01[ ,2],T02[ ,2],T03[ ,2],T04[ ,2],T05[ ,2],T06[ ,2],
         T07[ ,2],T08[ ,2],T09[ ,2],T10[ ,2],T11[ ,2],T12[ ,2],
         T13[ ,2],T14[ ,2],T15[ ,2],T16[ ,2],T17[ ,2],T18[ ,2],
         T19[ ,2],T20[ ,2])
Q<-cbind(T01[ ,3],T02[ ,3],T03[ ,3],T04[ ,3],T05[ ,3],T06[ ,3],
         T07[ ,3],T08[ ,3],T09[ ,3],T10[ ,3],T11[ ,3],T12[ ,3],
         T13[ ,3],T14[ ,3],T15[ ,3],T16[ ,3],T17[ ,3],T18[ ,3],
         T19[ ,3],T20[ ,3])

t<-T01[ ,1]
I<-seq(1,length(t),by=60)
par(mfrow=c(1,2),mar=c(1,1,0,0),oma=c(3,2,1,4))
matplot(t[I]/3600,apply(P,2,cumsum)[I, ]/3600,type="l",axes=FALSE)
box();axis(1);axis(2)
mtext("Time [hours]",side=1,line=2)
mtext("Acc. Presure (bar*hour)",side=2,line=2)
matplot(t[I]/3600,apply(Q,2,cumsum)[I, ]/3600,type="l",axes=FALSE)
box();axis(1);axis(4)
mtext("Time [hours]",side=1,line=2)
mtext("Acc. flow (m^3)",side=4,line=2)

par(mfrow=c(1,2),mar=c(1,1,0,0),oma=c(1,1,1,1))
matplot(t,apply(P[ ,1:5],2,cumsum),type="l",col=1)
matlines(t,apply(P[ ,6:10],2,cumsum),type="l",col=2)
matlines(t,apply(P[ ,11:14],2,cumsum),type="l",col=3)
matlines(t,apply(P[ ,15:16],2,cumsum),type="l",col=4)
matlines(t,apply(P[ ,17:20],2,cumsum),type="l",col=5)

matplot(t,apply(Q[ ,1:5],2,cumsum),type="l",col=1)
matlines(t,apply(Q[ ,6:10],2,cumsum),type="l",col=2)
matlines(t,apply(Q[ ,11:14],2,cumsum),type="l",col=3)
matlines(t,apply(Q[ ,15:16],2,cumsum),type="l",col=4)
matlines(t,apply(Q[ ,17:20],2,cumsum),type="l",col=5)


plotSeries<-function(P,Q,ylimP,ylimQ,ylabP,ylabQ,ser.no){
  t<-0:(dim(Q)[1]-1)
  I<-seq(1,length(t),by=1)
  Pn<-(P-ylimP[1])/diff(ylimP)
  Qn<-(Q-ylimQ[1])/diff(ylimQ)
  par(mfrow=c(dim(P)[2],1),mar=c(1,1,0,1),oma=c(3,4.5,2,3.5))
  nlab<-4
  print(dim(Pn))
  print(dim(Qn))
  for(i in 1:dim(P)[2]){
    matplot(t[I],cbind(Pn[I,i],Qn[I,i]),type="l",axes=FALSE,ylim=c(0,1),
            xlim=c(0,14400))
    box();
    axis(2,at=(ylabP-ylimP[1])/diff(ylimP),labels=ylabP)
    axis(4,at=(ylabQ-ylimQ[1])/diff(ylimQ),labels=ylabQ)
    mtext(ser.no[i],side=2,line=2.5)
  }
  axis(1)
  mtext("Time (sec)",side=1,line=2.5)
  mtext("P - black lines  Q - red lines",side=3,line=0.5,outer=TRUE)
  mtext("Presure (P) [bar]",side=2,line=3,outer=TRUE)
  mtext("Cross flow (Q) [m^3/hour]",side=4,line=2,outer=TRUE)
}

ser.no<-c("No. 1","No. 2","No. 3","No. 4","No. 5")
plotSeries(P[ ,1:5],Q[ ,1:5],ylimP=c(0.3,2.5),ylimQ=c(0,3.5),
           ylabP=seq(0.3,2.5,by=0.7),ylabQ=seq(0,3.5,by=1),ser.no)
ser.no<-c("No. 6","No. 7","No. 8","No. 9","No. 10")
plotSeries(P[ ,6:10],Q[ ,6:10],ylimP=c(0.3,2.3),ylimQ=c(0.2,3.5),
           ylabP=seq(0.3,2.3,by=0.6),ylabQ=seq(0.2,3.5,by=1),ser.no)

ser.no<-c("No. 11","No. 12","No. 13","No. 14","No. 15")
plotSeries(P[ ,11:15],Q[ ,11:15],ylimP=c(0.3,2.3),ylimQ=c(0.2,3.5),
           ylabP=seq(0.3,2.5,by=0.7),ylabQ=seq(0,3.5,by=1),ser.no)

ser.no<-c("No. 16","No. 17","No. 18","No. 19","No. 20")
plotSeries(P[ ,16:20],Q[ ,16:20],ylimP=c(0.3,2.3),ylimQ=c(0.2,3.5),
           ylabP=seq(0.3,2.5,by=0.7),ylabQ=seq(0,3.5,by=1),ser.no)

##################################################
## end
##################################################
