##################################################
## CTSM-R @: www.ctsm.info
## Simulation of the state
## By Jan Kloppenborg Moller (jkmo@dtu.dk)
## Please read the README.txt file of this folder
## License: GPL v2
##################################################

rm(list=ls())

source("predFuns.R")

library(ctsmr)

## load models 
load(file="Model1.Rdata")
load(file="Model2.Rdata")
load(file="Model3.Rdata")
load(file="Model4.Rdata")
load(file="Model5.Rdata")
load(file="Model6.Rdata")



##################################################
## Model 1
model1 <- Model1$fit$model
# Compile model
ctsmr:::Compile(model1)

# Set paremeters for 1-step prediction 
fake.fit1 <- Model1$fit
fit1 <- fake.fit1
fit1$xm[names(Model1$opt$par)] <- Model1$opt$par


##################################################
## Model 2
model2 <- Model2$fit$model
# Compile model
ctsmr:::Compile(model2)


# Set paremeters for 1-step prediction 
fake.fit2 <- Model2$fit
fit2 <- fake.fit2
fit2$xm[names(Model2$opt$par)] <- Model2$opt$par

##################################################
## Model 3
model3 <- Model3$fit$model
# Compile model
ctsmr:::Compile(model3)

# Set paremeters for 1-step prediction 
fake.fit3 <- Model3$fit
fit3 <- fake.fit3
fit3$xm[names(Model3$opt$par)] <- Model3$opt$par

##################################################
## Model 4
model4 <- Model4$fit$model
# Compile model
ctsmr:::Compile(model4)

# Set paremeters for 1-step prediction 
fake.fit4 <- Model4$fit
fit4 <- fake.fit4
fit4$xm[names(Model4$opt$par)]<-Model4$opt$par

##################################################
## Model 5
model5 <- Model5$fit$model
# Compile model
ctsmr:::Compile(model5)

# Set paremeters for 1-step prediction 
fake.fit5 <- Model5$fit
fit5 <- fake.fit5
fit5$xm[names(Model5$opt$par)]<-Model5$opt$par

###################################################
## Model 6
model6 <- Model6$fit$model
# Compile model
ctsmr:::Compile(model6)

# Set paremeters for 1-step prediction 
fake.fit6 <- Model6$fit
fit6 <-fake.fit6
fit6$xm[names(Model6$opt$par)]<-Model6$opt$par



##################################################
## Prediction and simulation (cannot run without data)
##################################################
pred1 <-PredSimFun(data,fit1,model1)
pred1$t <- pred1$t/3600

pred2 <-PredSimFun(data,fit2,model2)
pred2$t <- pred2$t/3600

pred3<-PredSimFun(data,fit3,model3)
pred3$t <- pred3$t/3600

pred4 <-PredSimFun(data,fit4, model4)
pred4$t <- pred4$t/3600

pred5<-PredSimFun(data,fit5,model5)
pred5$t <- pred5$t/3600

pred6 <-PredSimFun(data,fit6, model6)
pred6$t <- pred6$t/3600



##################################################
## Som scenario plots (run without data)
##################################################

##################################################
## Numbers calculated from data
Rm <- 0.58
VQ2 <- 0.004


data.tmp <- list()
Q <- c(0.85,1.77,2.68)
DP <- c(0.76,1.31,1.93)
k <- 0

for(i in 1:length(Q)){
    for(j in 1:length(DP)){
        k <- k+1
        data.tmp[[k]] <- data.frame(t = seq(0,4*3600,by=5), y = NA, DP=DP[j],
                                    Q=Q[i],
                                    VQ2=VQ2, OLQ=0, OLP=0,Rm=Rm)
    }
}

pred1.tmp<-SimFun(data.tmp,fit1,model1)
pred1.tmp$t<-pred1.tmp$t/3600

pred2.tmp<-SimFun(data.tmp,fit2,model2)
pred2.tmp$t<-pred2.tmp$t/3600

pred3.tmp<-SimFun(data.tmp,fit3,model3)
pred3.tmp$t<-pred3.tmp$t/3600

pred4.tmp<-SimFun(data.tmp,fit4,model4)
pred4.tmp$t<-pred4.tmp$t/3600

pred5.tmp<-SimFun(data.tmp,fit5,model5)
pred5.tmp$t<-pred5.tmp$t/3600

pred6.tmp<-SimFun(data.tmp,fit6,model6)
pred6.tmp$t<-pred6.tmp$t/3600



scenario.plot <- function(pred,ylim.state,main){
    par(mfrow=c(3,3),mar=c(0,0,1,1),oma=c(4,4,2,4))
    for(i in 1:9){
        I <- pred$ser==i

        matplot(pred$t[I], exp(cbind(pred$zsim[I],
                                     pred$zsim[I]-2*pred$sdzsim[I],
                                     pred$zsim[I]+2*pred$sdzsim[I])), type="l",
                col="white",ylab="",axes=FALSE,ylim=ylim.state)
        axis(1,at = 0:4,labels=rep("",5));box();
        if(i==1 | i==4 | i==7){axis(2)}
        if(i==3 | i==6 | i==9){axis(4)}
        if(i==7 | i==8 | i==9){axis(1)}
        legend("topleft", col = c(1, grey(0.5), "red"),
               legend = c(expression(omega["t|0"]), expression(CI(omega["t|0"]))),
               lty = c(1,1,2), bg = "white", lwd = c(1,7,1))
        polygon(c(pred$t[I], rev(pred$t[I])), exp(c(pred$zsim[I] - 2 * pred$sdzsim[I],
                                                    rev(pred$zsim[I] + 2 * pred$sdzsim[I]))),
                border = FALSE, col = gray(0.5))
        lines(pred$t[I], exp(pred$zsim[I]), col = 1, lty = 1)
        legend("topright",legend = c(paste("DP=",round(mean(pred$DP[I]),digits=2)),
                                     paste("Q =",round(mean(pred$Q[I]),digits=2))),
               bg = "white")
    }
    mtext(main,side=3,outer=TRUE)
}

ylim.state <- exp(range(pred2.tmp$zsim-2*pred2.tmp$sdzsim,
                    pred4.tmp$zsim+2*pred2.tmp$sdzsim))


## Scenario of state (cake) plot for each model
main <- "Fixed crossflow and pressure (Model 1)"
scenario.plot(pred1.tmp,ylim.state,main)

main <- "Fixed crossflow and pressure (Model 2)"
scenario.plot(pred2.tmp,ylim.state,main)

main <- "Fixed crossflow and pressure (Model 3)"
scenario.plot(pred3.tmp,ylim.state,main)

main <- "Fixed crossflow and pressure (Model 4)"
scenario.plot(pred4.tmp,ylim.state,main)

main <- "Fixed crossflow and pressure (Model 5)"
scenario.plot(pred5.tmp,ylim.state,main)

main <- "Fixed crossflow and pressure (Model 6)"
scenario.plot(pred6.tmp,ylim.state,main)





##################################################
## Scenario for flux (including unceartainty) Model 1
ylim.state <- range(pred2.tmp$Jsim-2*pred2.tmp$sdJsim,
                    pred2.tmp$Jsim+2*pred2.tmp$sdJsim)
par(mfrow=c(3,3),mar=c(0,0,1,1),oma=c(4,4,2,4))
for(i in 1:9){
    I <- pred1.tmp$ser==i

    matplot(pred1.tmp$t[I], cbind(pred1.tmp$Jsim[I], pred1.tmp$Jsim[I]-2*pred1.tmp$sdJsim[I],
                                 pred1.tmp$Jsim[I]+2*pred1.tmp$sdJsim[I]), type="l",
            col="white",ylab="",axes=FALSE,ylim=ylim.state)#,xlim=xlim)
    axis(1,at = 0:4,labels=rep("",5));box();
    if(i==1 | i==4 | i==7){axis(2)}
    if(i==3 | i==6 | i==9){axis(4)}
    if(i==7 | i==8 | i==9){axis(1)}
    legend("topleft", col = c(1, grey(0.5), "red"),
           legend = c(expression(J["t|0"]), expression(CI(J["t|0"]))),
           lty = c(1,1,2), bg = "white", lwd = c(1,7,1))
    polygon(c(pred1.tmp$t[I], rev(pred1.tmp$t[I])),
            c(pred1.tmp$Jsim[I] - 2 * pred1.tmp$sdJsim[I],
              rev(pred1.tmp$Jsim[I] + 2 * pred1.tmp$sdJsim[I])),
            border = FALSE, col = gray(0.5))
    lines(pred1.tmp$t[I], pred1.tmp$Jsim[I], col = 1, lty = 1)
    legend("topright",legend = c(
                          paste("DP=",round(mean(pred1.tmp$DP[I]),digits=2)),
                          paste("Q =",round(mean(pred1.tmp$Q[I]),digits=2))),
           bg = "white")

}
mtext("Fixed crossflow and pressure (Model 1)",side=3,outer=TRUE)

##################################################
## Scenario for flux (only mean)  for each model

## Model 1
ylim.state <- c(0,1.5)
par(mfcol=c(3,2),mar=c(2,1,1,1),oma=c(2,4,2,4))

I <- pred1.tmp$ser==1
plot(pred1.tmp$t[I], pred1.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
     main=paste("DP=",pred1.tmp$DP[I][1]))
I2 <- pred1.tmp$ser==4
lines(pred1.tmp$t[I2], pred1.tmp$Jsim[I2], type="l", col=2)
I3 <- pred1.tmp$ser==7
lines(pred1.tmp$t[I2], pred1.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("Q=",round(pred1.tmp$Q[I][1],digits=2)),
                           paste("Q=",round(pred1.tmp$Q[I2][1],digits=2)),
                           paste("Q=",round(pred1.tmp$Q[I3][1],digits=2))),
       col=1:3,lwd=1)


I <- pred1.tmp$ser==2
plot(pred1.tmp$t[I], pred1.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
      main=paste("DP=",pred1.tmp$DP[I][1]))
I2 <- pred1.tmp$ser==5
lines(pred1.tmp$t[I], pred1.tmp$Jsim[I2], type="l", col=2)
I3 <- pred1.tmp$ser==8
lines(pred1.tmp$t[I], pred1.tmp$Jsim[I3], type="l", col=3)

legend("topright",legend=c(paste("Q=",round(pred1.tmp$Q[I][1],digits=2)),
                           paste("Q=",round(pred1.tmp$Q[I2][1],digits=2)),
                           paste("Q=",round(pred1.tmp$Q[I3][1],digits=2))),
       col=1:3,lwd=1)


I <- pred1.tmp$ser==3
plot(pred1.tmp$t[I], pred1.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
      main=paste("DP=",pred1.tmp$DP[I][1]))
I2 <- pred1.tmp$ser==6
lines(pred1.tmp$t[I2], pred1.tmp$Jsim[I2], type="l", col=2)
I3 <- pred1.tmp$ser==9
lines(pred1.tmp$t[I2], pred1.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("Q=",round(pred1.tmp$Q[I][1],digits=2)),
                           paste("Q=",round(pred1.tmp$Q[I2][1],digits=2)),
                           paste("Q=",round(pred1.tmp$Q[I3][1],digits=2))),
       col=1:3,lwd=1)


I <- pred1.tmp$ser==1
plot(pred1.tmp$t[I], pred1.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
     main=paste("Q=",pred1.tmp$Q[I][1]),axes=FALSE)
axis(4);box();axis(1)
I2 <- pred1.tmp$ser==2
lines(pred1.tmp$t[I2], pred1.tmp$Jsim[I2], type="l", col=2)
I3 <- pred1.tmp$ser==3
lines(pred1.tmp$t[I2], pred1.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("DP=",round(pred1.tmp$DP[I][1],digits=2)),
                           paste("DP=",round(pred1.tmp$DP[I2][1],digits=2)),
                           paste("DP=",round(pred1.tmp$DP[I3][1],digits=2))),
       col=1:3,lwd=1)

I <- pred1.tmp$ser==4
plot(pred1.tmp$t[I], pred1.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
     main=paste("Q=",pred1.tmp$Q[I][1]),axes=FALSE)
axis(4);box();axis(1)
I2 <- pred1.tmp$ser==5
lines(pred1.tmp$t[I2], pred1.tmp$Jsim[I2], type="l", col=2)
I3 <- pred1.tmp$ser==6
lines(pred1.tmp$t[I2], pred1.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("DP=",round(pred1.tmp$DP[I][1],digits=2)),
                           paste("DP=",round(pred1.tmp$DP[I2][1],digits=2)),
                           paste("DP=",round(pred1.tmp$DP[I3][1],digits=2))),
       col=1:3,lwd=1)

I <- pred1.tmp$ser==7
plot(pred1.tmp$t[I], pred1.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
     main=paste("Q=",pred1.tmp$Q[I][1]),axes=FALSE)
axis(4);box();axis(1)
I2 <- pred1.tmp$ser==8
lines(pred1.tmp$t[I2], pred1.tmp$Jsim[I2], type="l", col=2)
I3 <- pred1.tmp$ser==9
lines(pred1.tmp$t[I2], pred1.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("DP=",round(pred1.tmp$DP[I][1],digits=2)),
                           paste("DP=",round(pred1.tmp$DP[I2][1],digits=2)),
                           paste("DP=",round(pred1.tmp$DP[I3][1],digits=2))),
       col=1:3,lwd=1)
mtext("Fixed crossflow and pressure (Model 1)",side=3,outer=TRUE)


## Model 2
ylim.state <- c(0,1.5)
par(mfcol=c(3,2),mar=c(2,1,1,1),oma=c(2,4,2,4))

I <- pred2.tmp$ser==1
plot(pred2.tmp$t[I], pred2.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
     main=paste("DP=",pred2.tmp$DP[I][1]))
I2 <- pred2.tmp$ser==4
lines(pred2.tmp$t[I2], pred2.tmp$Jsim[I2], type="l", col=2)
I3 <- pred2.tmp$ser==7
lines(pred2.tmp$t[I2], pred2.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("Q=",round(pred2.tmp$Q[I][1],digits=2)),
                           paste("Q=",round(pred2.tmp$Q[I2][1],digits=2)),
                           paste("Q=",round(pred2.tmp$Q[I3][1],digits=2))),
       col=1:3,lwd=1)

I <- pred2.tmp$ser==2
plot(pred2.tmp$t[I], pred2.tmp$Jsim[I], type="l", col="1",ylab="",
     ylim=ylim.state, main=paste("DP=",pred2.tmp$DP[I][1]))
I2 <- pred2.tmp$ser==5
lines(pred2.tmp$t[I], pred2.tmp$Jsim[I2], type="l", col=2)
I3 <- pred2.tmp$ser==8
lines(pred2.tmp$t[I], pred2.tmp$Jsim[I3], type="l", col=3)

legend("topright",legend=c(paste("Q=",round(pred2.tmp$Q[I][1],digits=2)),
                           paste("Q=",round(pred2.tmp$Q[I2][1],digits=2)),
                           paste("Q=",round(pred2.tmp$Q[I3][1],digits=2))),
       col=1:3,lwd=1)


I <- pred2.tmp$ser==3
plot(pred2.tmp$t[I], pred2.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
     main=paste("DP=",pred2.tmp$DP[I][1]))
I2 <- pred2.tmp$ser==6
lines(pred2.tmp$t[I2], pred2.tmp$Jsim[I2], type="l", col=2)
I3 <- pred2.tmp$ser==9
lines(pred2.tmp$t[I2], pred2.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("Q=",round(pred2.tmp$Q[I][1],digits=2)),
                           paste("Q=",round(pred2.tmp$Q[I2][1],digits=2)),
                           paste("Q=",round(pred2.tmp$Q[I3][1],digits=2))),
       col=1:3,lwd=1)


I <- pred2.tmp$ser==1
plot(pred2.tmp$t[I], pred2.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
     main=paste("Q=",pred2.tmp$Q[I][1]),axes=FALSE)
axis(4);box();axis(1)
I2 <- pred2.tmp$ser==2
lines(pred2.tmp$t[I2], pred2.tmp$Jsim[I2], type="l", col=2)
I3 <- pred2.tmp$ser==3
lines(pred2.tmp$t[I2], pred2.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("DP=",round(pred2.tmp$DP[I][1],digits=2)),
                           paste("DP=",round(pred2.tmp$DP[I2][1],digits=2)),
                           paste("DP=",round(pred2.tmp$DP[I3][1],digits=2))),
       col=1:3,lwd=1)

I <- pred2.tmp$ser==4
plot(pred2.tmp$t[I], pred2.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
     main=paste("Q=",pred2.tmp$Q[I][1]),axes=FALSE)
axis(4);box();axis(1)
I2 <- pred2.tmp$ser==5
lines(pred2.tmp$t[I2], pred2.tmp$Jsim[I2], type="l", col=2)
I3 <- pred2.tmp$ser==6
lines(pred2.tmp$t[I2], pred2.tmp$Jsim[I3], type="l",
            col=3)
legend("topright",legend=c(paste("DP=",round(pred2.tmp$DP[I][1],digits=2)),
                           paste("DP=",round(pred2.tmp$DP[I2][1],digits=2)),
                           paste("DP=",round(pred2.tmp$DP[I3][1],digits=2))),
       col=1:3,lwd=1)

I <- pred2.tmp$ser==7
plot(pred2.tmp$t[I], pred2.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
     main=paste("Q=",pred2.tmp$Q[I][1]),axes=FALSE)
axis(4);box();axis(1)
I2 <- pred2.tmp$ser==8
lines(pred2.tmp$t[I2], pred2.tmp$Jsim[I2], type="l", col=2)
I3 <- pred2.tmp$ser==9
lines(pred2.tmp$t[I2], pred2.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("DP=",round(pred2.tmp$DP[I][1],digits=2)),
                           paste("DP=",round(pred2.tmp$DP[I2][1],digits=2)),
                           paste("DP=",round(pred2.tmp$DP[I3][1],digits=2))),
       col=1:3,lwd=1)
mtext("Fixed crossflow and pressure (Model 2)",side=3,outer=TRUE)



## Model 3
ylim.state <- c(0,1.5)
par(mfcol=c(3,2),mar=c(2,1,1,1),oma=c(2,4,2,4))

I <- pred3.tmp$ser==1
plot(pred3.tmp$t[I], pred3.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
     main=paste("DP=",pred3.tmp$DP[I][1]))
I2 <- pred3.tmp$ser==4
lines(pred3.tmp$t[I2], pred3.tmp$Jsim[I2], type="l",
            col=2,lwd=3,lty=2)
I3 <- pred3.tmp$ser==7
lines(pred3.tmp$t[I3], pred3.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("Q=",round(pred3.tmp$Q[I][1],digits=2)),
                           paste("Q=",round(pred3.tmp$Q[I2][1],digits=2)),
                           paste("Q=",round(pred3.tmp$Q[I3][1],digits=2))),
       col=1:3,lwd=1)


I <- pred3.tmp$ser==2
plot(pred3.tmp$t[I], pred3.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
      main=paste("DP=",pred3.tmp$DP[I][1]))
I2 <- pred3.tmp$ser==5
lines(pred3.tmp$t[I], pred3.tmp$Jsim[I2], type="l", col=2,lwd=3,lty=2)
I3 <- pred3.tmp$ser==8
lines(pred3.tmp$t[I], pred3.tmp$Jsim[I3], type="l", col=3)

legend("topright",legend=c(paste("Q=",round(pred3.tmp$Q[I][1],digits=2)),
                           paste("Q=",round(pred3.tmp$Q[I2][1],digits=2)),
                           paste("Q=",round(pred3.tmp$Q[I3][1],digits=2))),
       col=1:3,lwd=1)


I <- pred3.tmp$ser==3
plot(pred3.tmp$t[I], pred3.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
      main=paste("DP=",pred3.tmp$DP[I][1]))
I2 <- pred3.tmp$ser==6
lines(pred3.tmp$t[I2], pred3.tmp$Jsim[I2], type="l", col=2,lwd=3,lty=2)
I3 <- pred3.tmp$ser==9
lines(pred3.tmp$t[I2], pred3.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("Q=",round(pred3.tmp$Q[I][1],digits=2)),
                           paste("Q=",round(pred3.tmp$Q[I2][1],digits=2)),
                           paste("Q=",round(pred3.tmp$Q[I3][1],digits=2))),
       col=1:3,lwd=1)


I <- pred3.tmp$ser==1
plot(pred3.tmp$t[I], pred3.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
     main=paste("Q=",pred3.tmp$Q[I][1]),axes=FALSE)
axis(4);box();axis(1)
I2 <- pred3.tmp$ser==2
lines(pred3.tmp$t[I2], pred3.tmp$Jsim[I2], type="l", col=2)
I3 <- pred3.tmp$ser==3
lines(pred3.tmp$t[I2], pred3.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("DP=",round(pred3.tmp$DP[I][1],digits=2)),
                           paste("DP=",round(pred3.tmp$DP[I2][1],digits=2)),
                           paste("DP=",round(pred3.tmp$DP[I3][1],digits=2))),
       col=1:3,lwd=1)

I <- pred3.tmp$ser==4
plot(pred3.tmp$t[I], pred3.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
     main=paste("Q=",pred3.tmp$Q[I][1]),axes=FALSE)
axis(4);box();axis(1)
I2 <- pred3.tmp$ser==5
lines(pred3.tmp$t[I2], pred3.tmp$Jsim[I2], type="l", col=2)
I3 <- pred3.tmp$ser==6
lines(pred3.tmp$t[I2], pred3.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("DP=",round(pred3.tmp$DP[I][1],digits=2)),
                           paste("DP=",round(pred3.tmp$DP[I2][1],digits=2)),
                           paste("DP=",round(pred3.tmp$DP[I3][1],digits=2))),
       col=1:3,lwd=1)

I <- pred3.tmp$ser==7
plot(pred3.tmp$t[I], pred3.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
     main=paste("Q=",pred3.tmp$Q[I][1]),axes=FALSE)
axis(4);box();axis(1)
I2 <- pred3.tmp$ser==8
lines(pred3.tmp$t[I2], pred3.tmp$Jsim[I2], type="l", col=2)
I3 <- pred3.tmp$ser==9
lines(pred3.tmp$t[I2], pred3.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("DP=",round(pred3.tmp$DP[I][1],digits=2)),
                           paste("DP=",round(pred3.tmp$DP[I2][1],digits=2)),
                           paste("DP=",round(pred3.tmp$DP[I3][1],digits=2))),
       col=1:3,lwd=1)
mtext("Fixed crossflow and pressure (Model 3)",side=3,outer=TRUE)


##################################################
## Model 4
ylim.state <- c(0,1.5)
par(mfcol=c(3,2),mar=c(2,1,1,1),oma=c(2,4,2,4))

I <- pred4.tmp$ser==1
plot(pred4.tmp$t[I], pred4.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
     main=paste("DP=",pred4.tmp$DP[I][1]))
I2 <- pred4.tmp$ser==4
lines(pred4.tmp$t[I2], pred4.tmp$Jsim[I2], type="l", col=2,lwd=3,lty=2)
I3 <- pred4.tmp$ser==7
lines(pred4.tmp$t[I3], pred4.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("Q=",round(pred4.tmp$Q[I][1],digits=2)),
                           paste("Q=",round(pred4.tmp$Q[I2][1],digits=2)),
                           paste("Q=",round(pred4.tmp$Q[I3][1],digits=2))),
       col=1:3,lwd=1)


I <- pred4.tmp$ser==2
plot(pred4.tmp$t[I], pred4.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
      main=paste("DP=",pred4.tmp$DP[I][1]))
I2 <- pred4.tmp$ser==5
lines(pred4.tmp$t[I], pred4.tmp$Jsim[I2], type="l", col=2,lwd=3,lty=2)
I3 <- pred4.tmp$ser==8
lines(pred4.tmp$t[I], pred4.tmp$Jsim[I3], type="l", col=3)

legend("topright",legend=c(paste("Q=",round(pred4.tmp$Q[I][1],digits=2)),
                           paste("Q=",round(pred4.tmp$Q[I2][1],digits=2)),
                           paste("Q=",round(pred4.tmp$Q[I3][1],digits=2))),
       col=1:3,lwd=1)


I <- pred4.tmp$ser==3
plot(pred4.tmp$t[I], pred4.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
      main=paste("DP=",pred4.tmp$DP[I][1]))
I2 <- pred4.tmp$ser==6
lines(pred4.tmp$t[I2], pred4.tmp$Jsim[I2], type="l", col=2,lwd=3,lty=2)
I3 <- pred4.tmp$ser==9
lines(pred4.tmp$t[I2], pred4.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("Q=",round(pred4.tmp$Q[I][1],digits=2)),
                           paste("Q=",round(pred4.tmp$Q[I2][1],digits=2)),
                           paste("Q=",round(pred4.tmp$Q[I3][1],digits=2))),
       col=1:3,lwd=1)


I <- pred4.tmp$ser==1
plot(pred4.tmp$t[I], pred4.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
     main=paste("Q=",pred4.tmp$Q[I][1]),axes=FALSE)
axis(4);box();axis(1)
I2 <- pred4.tmp$ser==2
lines(pred4.tmp$t[I2], pred4.tmp$Jsim[I2], type="l", col=2)
I3 <- pred4.tmp$ser==3
lines(pred4.tmp$t[I2], pred4.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("DP=",round(pred4.tmp$DP[I][1],digits=2)),
                           paste("DP=",round(pred4.tmp$DP[I2][1],digits=2)),
                           paste("DP=",round(pred4.tmp$DP[I3][1],digits=2))),
       col=1:3,lwd=1)

I <- pred4.tmp$ser==4
plot(pred4.tmp$t[I], pred4.tmp$Jsim[I], type="l",
     col="1",ylab="",ylim=ylim.state, main=paste("Q=",pred4.tmp$Q[I][1]),axes=FALSE)
axis(4);box();axis(1)
I2 <- pred4.tmp$ser==5
lines(pred4.tmp$t[I2], pred4.tmp$Jsim[I2], type="l", col=2)
I3 <- pred4.tmp$ser==6
lines(pred4.tmp$t[I2], pred4.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("DP=",round(pred4.tmp$DP[I][1],digits=2)),
                           paste("DP=",round(pred4.tmp$DP[I2][1],digits=2)),
                           paste("DP=",round(pred4.tmp$DP[I3][1],digits=2))),
       col=1:3,lwd=1)

I <- pred4.tmp$ser==7
plot(pred4.tmp$t[I], pred4.tmp$Jsim[I], type="l",
     col="1",ylab="",ylim=ylim.state, main=paste("Q=",pred4.tmp$Q[I][1]),axes=FALSE)
axis(4);box();axis(1)
I2 <- pred4.tmp$ser==8
lines(pred4.tmp$t[I2], pred4.tmp$Jsim[I2], type="l", col=2)
I3 <- pred4.tmp$ser==9
lines(pred4.tmp$t[I2], pred4.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("DP=",round(pred4.tmp$DP[I][1],digits=2)),
                           paste("DP=",round(pred4.tmp$DP[I2][1],digits=2)),
                           paste("DP=",round(pred4.tmp$DP[I3][1],digits=2))),
       col=1:3,lwd=1)
mtext("Fixed crossflow and pressure (Model 4)",side=3,outer=TRUE)


##################################################
## Model 5
ylim.state <- c(0,1.5)
par(mfcol=c(3,2),mar=c(2,1,1,1),oma=c(2,4,2,4))

I <- pred5.tmp$ser==1
plot(pred5.tmp$t[I], pred5.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
     main=paste("DP=",pred5.tmp$DP[I][1]))
I2 <- pred5.tmp$ser==4
lines(pred5.tmp$t[I2], pred5.tmp$Jsim[I2], type="l", col=2,lwd=3,lty=2)
I3 <- pred5.tmp$ser==7
lines(pred5.tmp$t[I3], pred5.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("Q=",round(pred5.tmp$Q[I][1],digits=2)),
                           paste("Q=",round(pred5.tmp$Q[I2][1],digits=2)),
                           paste("Q=",round(pred5.tmp$Q[I3][1],digits=2))),
       col=1:3,lwd=1)


I <- pred5.tmp$ser==2
plot(pred5.tmp$t[I], pred5.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
      main=paste("DP=",pred5.tmp$DP[I][1]))
I2 <- pred5.tmp$ser==5
lines(pred5.tmp$t[I], pred5.tmp$Jsim[I2], type="l", col=2,lwd=3,lty=2)
I3 <- pred5.tmp$ser==8
lines(pred5.tmp$t[I], pred5.tmp$Jsim[I3], type="l", col=3)

legend("topright",legend=c(paste("Q=",round(pred5.tmp$Q[I][1],digits=2)),
                           paste("Q=",round(pred5.tmp$Q[I2][1],digits=2)),
                           paste("Q=",round(pred5.tmp$Q[I3][1],digits=2))),
       col=1:3,lwd=1)


I <- pred5.tmp$ser==3
plot(pred5.tmp$t[I], pred5.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
      main=paste("DP=",pred5.tmp$DP[I][1]))
I2 <- pred5.tmp$ser==6
lines(pred5.tmp$t[I2], pred5.tmp$Jsim[I2], type="l", col=2,lwd=3,lty=2)
I3 <- pred5.tmp$ser==9
lines(pred5.tmp$t[I2], pred5.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("Q=",round(pred5.tmp$Q[I][1],digits=2)),
                           paste("Q=",round(pred5.tmp$Q[I2][1],digits=2)),
                           paste("Q=",round(pred5.tmp$Q[I3][1],digits=2))),
       col=1:3,lwd=1)


I <- pred5.tmp$ser==1
plot(pred5.tmp$t[I], pred5.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
     main=paste("Q=",pred5.tmp$Q[I][1]),axes=FALSE)
axis(4);box();axis(1)
I2 <- pred5.tmp$ser==2
lines(pred5.tmp$t[I2], pred5.tmp$Jsim[I2], type="l", col=2)
I3 <- pred5.tmp$ser==3
lines(pred5.tmp$t[I2], pred5.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("DP=",round(pred5.tmp$DP[I][1],digits=2)),
                           paste("DP=",round(pred5.tmp$DP[I2][1],digits=2)),
                           paste("DP=",round(pred5.tmp$DP[I3][1],digits=2))),
       col=1:3,lwd=1)

I <- pred5.tmp$ser==4
plot(pred5.tmp$t[I], pred5.tmp$Jsim[I], type="l",
     col="1",ylab="",ylim=ylim.state, main=paste("Q=",pred5.tmp$Q[I][1]),axes=FALSE)
axis(4);box();axis(1)
I2 <- pred5.tmp$ser==5
lines(pred5.tmp$t[I2], pred5.tmp$Jsim[I2], type="l", col=2)
I3 <- pred5.tmp$ser==6
lines(pred5.tmp$t[I2], pred5.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("DP=",round(pred5.tmp$DP[I][1],digits=2)),
                           paste("DP=",round(pred5.tmp$DP[I2][1],digits=2)),
                           paste("DP=",round(pred5.tmp$DP[I3][1],digits=2))),
       col=1:3,lwd=1)

I <- pred5.tmp$ser==7
plot(pred5.tmp$t[I], pred5.tmp$Jsim[I], type="l",
     col="1",ylab="",ylim=ylim.state, main=paste("Q=",pred5.tmp$Q[I][1]),axes=FALSE)
axis(4);box();axis(1)
I2 <- pred5.tmp$ser==8
lines(pred5.tmp$t[I2], pred5.tmp$Jsim[I2], type="l", col=2)
I3 <- pred5.tmp$ser==9
lines(pred5.tmp$t[I2], pred5.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("DP=",round(pred5.tmp$DP[I][1],digits=2)),
                           paste("DP=",round(pred5.tmp$DP[I2][1],digits=2)),
                           paste("DP=",round(pred5.tmp$DP[I3][1],digits=2))),
       col=1:3,lwd=1)
mtext("Fixed crossflow and pressure (Model 5)",side=3,outer=TRUE)


## Model 6
ylim.state <- c(0,1.5)
par(mfcol=c(3,2),mar=c(2,1,1,1),oma=c(2,4,2,4))

I <- pred6.tmp$ser==1
plot(pred6.tmp$t[I], pred6.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
     main=paste("DP=",pred6.tmp$DP[I][1]))
I2 <- pred6.tmp$ser==4
lines(pred6.tmp$t[I2], pred6.tmp$Jsim[I2], type="l", col=2,lwd=3,lty=2)
I3 <- pred6.tmp$ser==7
lines(pred6.tmp$t[I3], pred6.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("Q=",round(pred6.tmp$Q[I][1],digits=2)),
                           paste("Q=",round(pred6.tmp$Q[I2][1],digits=2)),
                           paste("Q=",round(pred6.tmp$Q[I3][1],digits=2))),
       col=1:3,lwd=1)


I <- pred6.tmp$ser==2
plot(pred6.tmp$t[I], pred6.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
      main=paste("DP=",pred6.tmp$DP[I][1]))
I2 <- pred6.tmp$ser==5
lines(pred6.tmp$t[I], pred6.tmp$Jsim[I2], type="l", col=2,lwd=3,lty=2)
I3 <- pred6.tmp$ser==8
lines(pred6.tmp$t[I], pred6.tmp$Jsim[I3], type="l", col=3)

legend("topright",legend=c(paste("Q=",round(pred6.tmp$Q[I][1],digits=2)),
                           paste("Q=",round(pred6.tmp$Q[I2][1],digits=2)),
                           paste("Q=",round(pred6.tmp$Q[I3][1],digits=2))),
       col=1:3,lwd=1)


I <- pred6.tmp$ser==3
plot(pred6.tmp$t[I], pred6.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
     main=paste("DP=",pred6.tmp$DP[I][1]))
I2 <- pred6.tmp$ser==6
lines(pred6.tmp$t[I2], pred6.tmp$Jsim[I2], type="l", col=2,lwd=3,lty=2)
I3 <- pred6.tmp$ser==9
lines(pred6.tmp$t[I2], pred6.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("Q=",round(pred6.tmp$Q[I][1],digits=2)),
                           paste("Q=",round(pred6.tmp$Q[I2][1],digits=2)),
                           paste("Q=",round(pred6.tmp$Q[I3][1],digits=2))),
       col=1:3,lwd=1)


I <- pred6.tmp$ser==1
plot(pred6.tmp$t[I], pred6.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
     main=paste("Q=",pred6.tmp$Q[I][1]),axes=FALSE)
axis(4);box();axis(1)
I2 <- pred6.tmp$ser==2
lines(pred6.tmp$t[I2], pred6.tmp$Jsim[I2], type="l", col=2)
I3 <- pred6.tmp$ser==3
lines(pred6.tmp$t[I2], pred6.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("DP=",round(pred6.tmp$DP[I][1],digits=2)),
                           paste("DP=",round(pred6.tmp$DP[I2][1],digits=2)),
                           paste("DP=",round(pred6.tmp$DP[I3][1],digits=2))),
       col=1:3,lwd=1)

I <- pred6.tmp$ser==4
plot(pred6.tmp$t[I], pred6.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
     main=paste("Q=",pred6.tmp$Q[I][1]),axes=FALSE)
axis(4);box();axis(1)
I2 <- pred6.tmp$ser==5
lines(pred6.tmp$t[I2], pred6.tmp$Jsim[I2], type="l", col=2)
I3 <- pred6.tmp$ser==6
lines(pred6.tmp$t[I2], pred6.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("DP=",round(pred6.tmp$DP[I][1],digits=2)),
                           paste("DP=",round(pred6.tmp$DP[I2][1],digits=2)),
                           paste("DP=",round(pred6.tmp$DP[I3][1],digits=2))),
       col=1:3,lwd=1)

I <- pred6.tmp$ser==7
plot(pred6.tmp$t[I], pred6.tmp$Jsim[I], type="l", col="1",ylab="",ylim=ylim.state,
     main=paste("Q=",pred6.tmp$Q[I][1]),axes=FALSE)
axis(4);box();axis(1)
I2 <- pred6.tmp$ser==8
lines(pred6.tmp$t[I2], pred6.tmp$Jsim[I2], type="l", col=2)
I3 <- pred6.tmp$ser==9
lines(pred6.tmp$t[I2], pred6.tmp$Jsim[I3], type="l", col=3)
legend("topright",legend=c(paste("DP=",round(pred6.tmp$DP[I][1],digits=2)),
                           paste("DP=",round(pred6.tmp$DP[I2][1],digits=2)),
                           paste("DP=",round(pred6.tmp$DP[I3][1],digits=2))),
       col=1:3,lwd=1)
mtext("Fixed crossflow and pressure (Model 6)",side=3,outer=TRUE)


##################################################
##
##################################################


##################################################
## Tables

## extract number for parameter table
par1 <- Model1$opt$par
Vpar1 <- solve(Model1$H)
sdpar1 <- sqrt(diag(Vpar1))


par2 <- Model2$opt$par
Vpar2 <- solve(Model2$H)
sdpar2 <- sqrt(diag(Vpar2))

par3 <- Model3$opt$par
Vpar3 <- solve(Model3$H)
sdpar3 <- sqrt(diag(Vpar3))

par4 <- Model4$opt$par
Vpar4 <- solve(Model4$H)
sdpar4 <- sqrt(diag(Vpar4))

par5 <- Model5$opt$par
Vpar5 <- solve(Model5$H)
sdpar5 <- sqrt(diag(Vpar5))

par6 <- Model6$opt$par
Vpar6 <- solve(Model6$H)
sdpar6 <- sqrt(diag(Vpar6))


## Set up latex table
par.tab <- matrix(NA,ncol=6,nrow=24)
rownames(par.tab) <- c("ll","df","AIC","BIC","$\\omega_0$","$CI_{\\omega_0}$","$C_b$","$CI_{C_b}$","$Pa$","$CI_{Pa}$",
                       "$J_{ss}$","$CI_{J_{ss}}$","$\\omega_C$","$CI_{\\omega_C}$","$\\sigma$","$CI_{\\sigma}$",
                       "$\\sigma_P$","$CI_{\\sigma_P}$","$\\sigma_Q$","$CI_{\\sigma_Q}$",
                       "$s_Q$","$CI_{s_Q}$","$s$","$CI_{s}$")

par.tab["ll", ] <- round(c(-Model1$opt$objective,-Model2$opt$objective,-Model3$opt$objective,
                           -Model4$opt$objective,-Model5$opt$objective,
                           -Model6$opt$objective),digits=0)
par.tab["df", ] <- round(c(length(Model1$opt$par),length(Model2$opt$par),length(Model3$opt$par),
                           length(Model4$opt$par),length(Model5$opt$par),
                           length(Model6$opt$par)),digits=0)
par.tab["AIC",] <- round(c(Model1$opt$objective+2*length(Model1$opt$par),
                           Model2$opt$objective+2*length(Model2$opt$par),
                           Model3$opt$objective+2*length(Model3$opt$par),
                           Model4$opt$objective+2*length(Model4$opt$par),
                           Model5$opt$objective+2*length(Model5$opt$par),
                           Model6$opt$objective+2*length(Model6$opt$par)),digits=0)
par.tab["BIC", ] <- round(c(Model1$opt$objective+length(Model1$opt$par)*log(dim(pred2)[1]),
                            Model2$opt$objective+length(Model2$opt$par)*log(dim(pred2)[1]),
                            Model3$opt$objective+length(Model3$opt$par)*log(dim(pred2)[1]),
                            Model4$opt$objective+length(Model4$opt$par)*log(dim(pred2)[1]),
                            Model5$opt$objective+length(Model5$opt$par)*log(dim(pred2)[1]),
                            Model6$opt$objective+length(Model6$opt$par)*log(dim(pred2)[1])),
                          digits=0)
par.tab

digits <- 2
par.tab["$\\omega_0$", ] <- round(exp(c(par1["z0"],par2["z0"],par3["z0"],par4["z0"],
                                        par5["z0"],par6["z0"])),digits=digits)
par.tab["$CI_{\\omega_0}$", ] <-
    c(paste("{\\small $(",round(exp(par1["z0"]-2*sdpar1["z0"]),digits=digits),
            ";",round(exp(par1["z0"]+2*sdpar1["z0"]),digits=digits),")$}",sep=""),
      paste("{\\small $(",round(exp(par2["z0"]-2*sdpar2["z0"]),digits=digits),
            ";",round(exp(par2["z0"]+2*sdpar2["z0"]),digits=digits),")$}",sep=""),
      paste("{\\small $(",round(exp(par3["z0"]-2*sdpar3["z0"]),digits=digits),
            ";",round(exp(par3["z0"]+2*sdpar3["z0"]),digits=digits),")$}",sep=""),
      paste("{\\small $(",round(exp(par4["z0"]-2*sdpar4["z0"]),digits=digits),
            ";",round(exp(par4["z0"]+2*sdpar4["z0"]),digits=digits),")$}",sep=""),
      paste("{\\small $(",round(exp(par5["z0"]-2*sdpar5["z0"]),digits=digits),
            ";",round(exp(par5["z0"]+2*sdpar5["z0"]),digits=digits),")$}",sep=""),
      paste("{\\small $(",round(exp(par6["z0"]-2*sdpar6["z0"]),digits=digits),
            ";",round(exp(par6["z0"]+2*sdpar6["z0"]),digits=digits),")$}",sep=""))

par.tab

digits<-5
par.tab["$C_b$", ] <- round(exp(c(par1["Cb"],par2["Cb"],par3["Cb"],par4["Cb"],
                                  par6["Cb"],par6["Cb"])),digits=digits)
par.tab["$CI_{C_b}$",] <-
    c(paste("{\\small$(",round(exp(par1["Cb"]-2*sdpar1["Cb"]),digits=digits),
            ";",round(exp(par1["Cb"]+2*sdpar1["Cb"]),digits=digits),")$}",sep=""),
      paste("{\\small$(",round(exp(par2["Cb"]-2*sdpar2["Cb"]),digits=digits),
            ";",round(exp(par2["Cb"]+2*sdpar2["Cb"]),digits=digits),")$}",sep=""),
      paste("{\\small$(",round(exp(par3["Cb"]-2*sdpar3["Cb"]),digits=digits),
            ";",round(exp(par3["Cb"]+2*sdpar3["Cb"]),digits=digits),")$}",sep=""),
      paste("{\\small$(",round(exp(par4["Cb"]-2*sdpar4["Cb"]),digits=digits),
            ";",round(exp(par4["Cb"]+2*sdpar4["Cb"]),digits=digits),")$}",sep=""),
      paste("{\\small$(",round(exp(par5["Cb"]-2*sdpar5["Cb"]),digits=digits),
            ";",round(exp(par5["Cb"]+2*sdpar5["Cb"]),digits=digits),")$}",sep=""),
      paste("{\\small$(",round(exp(par6["Cb"]-2*sdpar6["Cb"]),digits=digits),
          ";",round(exp(par6["Cb"]+2*sdpar6["Cb"]),digits=digits),")$}",sep=""))

digits <- 2
par.tab["$Pa$", ] <- c(round(exp(c(par1["Pa"],par2["Pa"],par3["Pa"],par4["Pa"])),digits=digits),
                             "Func.\\tablefootnote{$Pa=e^{Pa_0+Pa_I\\cdot I/3600}$, see Figure \\ref{fig:Effects}.}",
                             "Func.\\tablefootnote{$Pa=e^{Pa_0+Pa_{\\omega}\\cdot \\omega}$, see Figure \\ref{fig:Effects}.}")
par.tab["$CI_{Pa}$",] <-
    c(paste("{\\small$(",round(exp(par1["Pa"]-2*sdpar1["Pa"]),digits=digits),
            ";",round(exp(par1["Pa"]+2*sdpar1["Pa"]),digits=digits),")$}",sep=""),
      paste("{\\small$(",round(exp(par2["Pa"]-2*sdpar2["Pa"]),digits=digits),
            ";",round(exp(par2["Pa"]+2*sdpar2["Pa"]),digits=digits),")$}",sep=""),
      paste("{\\small$(",round(exp(par3["Pa"]-2*sdpar3["Pa"]),digits=digits),
            ";",round(exp(par3["Pa"]+2*sdpar3["Pa"]),digits=digits),")$}",sep=""),
      paste("{\\small$(",round(exp(par4["Pa"]-2*sdpar4["Pa"]),digits=digits),
            ";",round(exp(par4["Pa"]+2*sdpar4["Pa"]),digits=digits),")$}",sep=""),"",""
)

par.tab["$J_{ss}$", ] <- c(round(exp(c(par1["mu"])),digits=digits),
                           "Poly\\tablefootnote{$J_ss=e^{\\mu_0+\\mu_1Q+\\mu_2Q^2}$, see Figure \\ref{fig:Effects}.}",
                           "Func.\\tablefootnote{$J_{ss}=frac{e^{\\mu_0}}{1+e^{\\alpha_{\\mu}(Q-Q_0)}}$, see Figure \\ref{fig:Effects}.}",
                           "Func.\\tablefootnote{$J_ss=\\mu_0Q^{\\gamma}$, see Figure \\ref{fig:Effects}.}",
                           "Poly\\tablefootnote{$J_ss=e^{\\mu_0+\\mu_1Q+\\mu_2Q^2}$, see Figure \\ref{fig:Effects}.}",
                           "Poly\\tablefootnote{$J_ss=e^{\\mu_0+\\mu_1Q+\\mu_2Q^2}$, see Figure \\ref{fig:Effects}.}"
)
par.tab["$CI_{J_{ss}}$",1] <-
    c(paste("{\\small$(",round(exp(par1["mu"]-2*sdpar1["mu"]),digits=digits),
            ";",round(exp(par1["mu"]+2*sdpar1["mu"]),digits=digits),")$}",sep=""))



digits <- 3
par.tab["$\\omega_C$", ] <- round(exp(c(-par1["omegaC"],-par2["omegaC"],-par3["omegaC"])),digits=digits)
par.tab["$CI_{\\omega_C}$", ] <-
    c(paste("{\\small$(",round(exp(-par1["omegaC"]-2*sdpar1["omegaC"]),digits=digits),
            ";",round(exp(-par1["omegaC"]+2*sdpar1["omegaC"]),digits=digits),")$}",sep=""),
      paste("{\\small$(",round(exp(-par2["omegaC"]-2*sdpar2["omegaC"]),digits=digits),
            ";",round(exp(-par2["omegaC"]+2*sdpar2["omegaC"]),digits=digits),")$}",sep=""),
      paste("{\\small$(",round(exp(-par3["omegaC"]-2*sdpar3["omegaC"]),digits=digits),
            ";",round(exp(-par3["omegaC"]+2*sdpar3["omegaC"]),digits=digits),")$}",sep=""),
      paste("{\\small$(",round(exp(-par4["omegaC"]-2*sdpar4["omegaC"]),digits=digits),
            ";",round(exp(-par4["omegaC"]+2*sdpar4["omegaC"]),digits=digits),")$}",sep=""),
      paste("{\\small$(",round(exp(-par5["omegaC"]-2*sdpar5["omegaC"]),digits=digits),
            ";",round(exp(-par5["omegaC"]+2*sdpar5["omegaC"]),digits=digits),")$}",sep=""),
      paste("{\\small$(",round(exp(-par6["omegaC"]-2*sdpar6["omegaC"]),digits=digits),
            ";",round(exp(-par6["omegaC"]+2*sdpar6["omegaC"]),digits=digits),")$}",sep=""))



digits <- 4
par.tab["$\\sigma$", ] <- round(exp(c(par1["sigma"],par2["sigma"],par3["sigma"])),digits=digits)
par.tab["$CI_{\\sigma}$", ] <-
    c(paste("{\\small $(",round(exp(par1["sigma"]-2*sdpar1["sigma"]),digits=digits),
            ";",round(exp(par1["sigma"]+2*sdpar1["sigma"]),digits=digits),")$}",sep=""),
      paste("{\\small $(",round(exp(par2["sigma"]-2*sdpar2["sigma"]),digits=digits),
            ";",round(exp(par2["sigma"]+2*sdpar2["sigma"]),digits=digits),")$}",sep=""),
      paste("{\\small $(",round(exp(par3["sigma"]-2*sdpar3["sigma"]),digits=digits),
            ";",round(exp(par3["sigma"]+2*sdpar3["sigma"]),digits=digits),")$}",sep=""))

digits <- 3
par.tab["$\\sigma_P$", ] <- round(c(par1["sigP"],par2["sigP"],par3["sigP"],
                                    par4["sigP"],par5["sigP"],par6["sigP"]),digits=digits)
par.tab["$CI_{\\sigma_P}$", ] <-
    c(paste("{\\small $(",round(par1["sigP"]-2*sdpar1["sigP"],digits=digits),
            ";",round(par1["sigP"]+2*sdpar1["sigP"],digits=digits),")$}",sep=""),
      paste("{\\small $(",round(par2["sigP"]-2*sdpar2["sigP"],digits=digits),
            ";",round(par2["sigP"]+2*sdpar2["sigP"],digits=digits),")$}",sep=""),
      paste("{\\small $(",round(par3["sigP"]-2*sdpar3["sigP"],digits=digits),
            ";",round(par3["sigP"]+2*sdpar3["sigP"],digits=digits),")$}",sep=""),
      paste("{\\small $(",round(par4["sigP"]-2*sdpar4["sigP"],digits=digits),
            ";",round(par4["sigP"]+2*sdpar4["sigP"],digits=digits),")$}",sep=""),
      paste("{\\small $(",round(par5["sigP"]-2*sdpar5["sigP"],digits=digits),
            ";",round(par5["sigP"]+2*sdpar5["sigP"],digits=digits),")$}",sep=""),
      paste("{\\small $(",round(par6["sigP"]-2*sdpar6["sigP"],digits=digits),
          ";",round(par6["sigP"]+2*sdpar6["sigP"],digits=digits),")$}",sep=""))

par.tab["$\\sigma_Q$", ] <- round(c(par1["sigQ"],par2["sigQ"],par3["sigQ"],
                                  par4["sigQ"],par5["sigQ"],par6["sigQ"]),digits=digits)
digits <- 2
par.tab["$CI_{\\sigma_Q}$", ] <-
    c(paste("{\\small $(",round(par1["sigQ"]-2*sdpar1["sigQ"],digits=digits),
            ";",round(par1["sigQ"]+2*sdpar1["sigQ"],digits=digits),")$}",sep=""),
      paste("{\\small $(",round(par2["sigQ"]-2*sdpar2["sigQ"],digits=digits),
            ";",round(par2["sigQ"]+2*sdpar2["sigQ"],digits=digits),")$}",sep=""),
      paste("{\\small $(",round(par3["sigQ"]-2*sdpar3["sigQ"],digits=digits),
          ";",round(par3["sigQ"]+2*sdpar3["sigQ"],digits=digits),")$}",sep=""))

digits <- 2
par.tab["$s_Q$", ] <- round(exp(c(par1["sq"],par2["sq"],par3["sq"],par4["sq"],
                                  par5["sq"],par6["sq"])),digits=digits)
par.tab["$CI_{s_Q}$", ] <-
    c(paste("{\\small $(",round(exp(par1["sq"]-2*sdpar1["sq"]),digits=digits),
            ";",round(exp(par1["sq"]+2*sdpar1["sq"]),digits=digits),")$}",sep=""),
      paste("{\\small $(",round(exp(par2["sq"]-2*sdpar2["sq"]),digits=digits),
            ";",round(exp(par2["sq"]+2*sdpar2["sq"]),digits=digits),")$}",sep=""),
      paste("{\\small $(",round(exp(par3["sq"]-2*sdpar3["sq"]),digits=digits),
            ";",round(exp(par3["sq"]+2*sdpar3["sq"]),digits=digits),")$}",sep=""),
      paste("{\\small $(",round(exp(par4["sq"]-2*sdpar4["sq"]),digits=digits),
            ";",round(exp(par4["sq"]+2*sdpar4["sq"]),digits=digits),")$}",sep=""),
      paste("{\\small $(",round(exp(par5["sq"]-2*sdpar5["sq"]),digits=digits),
            ";",round(exp(par5["sq"]+2*sdpar5["sq"]),digits=digits),")$}",sep=""),
      paste("{\\small $(",round(exp(par6["sq"]-2*sdpar6["sq"]),digits=digits),
            ";",round(exp(par6["sq"]+2*sdpar6["sq"]),digits=digits),")$}",sep=""))
      
digits <- 2
par.tab["$s$", ] <- round(exp(c(par1["sq2"],par2["sq2"],par3["sq2"],par4["sq2"],
                                par5["sq2"],par6["sq2"])),digits=digits)
par.tab["$CI_{s}$", ] <-
    c(paste("{\\small $(",round(exp(par1["sq2"]-2*sdpar1["sq2"]),digits=digits),
            ";",round(exp(par1["sq2"]+2*sdpar1["sq2"]),digits=digits),")$}",sep=""),
      paste("{\\small $(",round(exp(par2["sq2"]-2*sdpar2["sq2"]),digits=digits),
            ";",round(exp(par2["sq2"]+2*sdpar2["sq2"]),digits=digits),")$}",sep=""),
      paste("{\\small $(",round(exp(par3["sq2"]-2*sdpar3["sq2"]),digits=digits),
            ";",round(exp(par3["sq2"]+2*sdpar3["sq2"]),digits=digits),")$}",sep=""),
      paste("{\\small $(",round(exp(par4["sq2"]-2*sdpar4["sq2"]),digits=digits),
            ";",round(exp(par4["sq2"]+2*sdpar4["sq2"]),digits=digits),")$}",sep=""),
      paste("{\\small $(",round(exp(par5["sq2"]-2*sdpar5["sq2"]),digits=digits),
            ";",round(exp(par5["sq2"]+2*sdpar5["sq2"]),digits=digits),")$}",sep=""),
      paste("{\\small $(",round(exp(par6["sq2"]-2*sdpar6["sq2"]),digits=digits),
            ";",round(exp(par6["sq2"]+2*sdpar6["sq2"]),digits=digits),")$}",sep=""))

colnames(par.tab) <- c("Model1","Model2","Model3","Model4","Model5","Model6")
par.tab
library(xtable)
partab1<-print(xtable(par.tab,display=c("f","f","f","f","f","f","f"),
                      digits=c(1,1,1,1,1,1,1),label="tab:partab1",align="lrrrrrr",
                   caption=paste("Estimation results for models)")),
                   caption.placement="top",  
            type="latex",sanitize.text.function = function(x){x})

##################################################
## Flux evaluation (does not run without data)
##################################################

tab <- matrix(NA,ncol=6,nrow=24)
rownames(tab) <- c(1:23,"Total")
colnames(tab) <- c("M1","M2","M3","M4","M5","M6")
## Calculate RMSE for each series 
for(i in 1:23){
    I <- pred1$ser==i
    tab[i,6] <- sqrt(mean((pred6$y[I]-pred6$Jsim[I])^2))
    tab[i,5] <- sqrt(mean((pred5$y[I]-pred5$Jsim[I])^2))
    tab[i,4] <- sqrt(mean((pred4$y[I]-pred4$Jsim[I])^2))
    tab[i,3] <- sqrt(mean((pred3$y[I]-pred3$Jsim[I])^2))
    tab[i,2] <- sqrt(mean((pred2$y[I]-pred2$Jsim[I])^2))
    tab[i,1] <- sqrt(mean((pred1$y[I]-pred1$Jsim[I])^2))
}

## RMSE for all observations
tab[24,1] <- sqrt(mean((pred1$y-pred1$Jsim)^2))
tab[24,2] <- sqrt(mean((pred2$y-pred2$Jsim)^2))
tab[24,3] <- sqrt(mean((pred3$y-pred3$Jsim)^2))
tab[24,4] <- sqrt(mean((pred4$y-pred4$Jsim)^2))
tab[24,5] <- sqrt(mean((pred5$y-pred5$Jsim)^2))
tab[24,6] <- sqrt(mean((pred6$y-pred6$Jsim)^2))

## Remaining is setting up latex tables 
J <- numeric(23)
for(i in 1:23){
    J[i] <- mean(pred1[pred1$ser==i,"y"])
}
index <- sort(J,index.return=TRUE)$ix
tab <- tab[c(index,24), ]
tab.tmp<-tab
tab.tmp <- cbind(J=c(sort(J),mean(pred1$y)),tab)

tab <- round(tab,digits=3)


for(j in 1:24){
    i <- which(tab.tmp[j,]==min(tab.tmp[j,]))
    tab[j,i]<-paste("$\\boldsymbol{",tab[j,i],"}$")
}

tab <- cbind(J=round(c(sort(J),mean(pred1$y)),digits=3),tab)

library(xtable)
valtab1<-print(xtable(tab,display=c("f","f","f","f","f","f","f","f"),
                      digits=c(1,3,3,3,3,3,3,3),label="tab:validationtab1",align="lrrrrrrr",
                   caption=paste("Validation results for models")),
                   caption.placement="top",  
            type="latex",sanitize.text.function = function(x){x})


##################################################
## End
##################################################

